﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Drawing;
using System.Threading.Tasks;
using PropertyGridDemo;
using PropertyGridDemo.Properties;

namespace PropertyGridDemo.Objects
{
    public abstract class Shape
    {
        protected string _name;

        public Shape()
        {
            ShapeSize = new Size(16, 16);
            ShapeColor = Color.White;
        }
        public Shape(Size sz, Color c)
        {
            ShapeSize = sz;
            ShapeColor = c;
        }
        [DisplayNameGlobal("NAME_SHAPESIZE")]
        [DescriptionGlobal("DESC_SHAPESIZE")]
        public Size ShapeSize { get; set; }
        [DisplayNameGlobal("NAME_SHAPECOLOR")]
        [DescriptionGlobal("DESC_SHAPECOLOR")]
        public Color ShapeColor { get; set; }
        public abstract void DrawShape(Graphics gr, int x, int y);
        public override string ToString()
        {
            return _name;
        }
    }
    public class Circle : Shape
    {
        public Circle()
            : base()
        {
            _name = Resources.SHAPE_CIRCLE;
        }
        public Circle(Size sz, Color c)
            : base(sz, c)
        {
            _name = Resources.SHAPE_CIRCLE;
        }
        public override void DrawShape(Graphics gr, int x, int y)
        {
            Pen p = new Pen(ShapeColor);
            gr.DrawEllipse(p, new Rectangle(x, y, ShapeSize.Width, ShapeSize.Height));
            p.Dispose();
        }
    }
    public class Box : Shape
    {
        public Box()
            : base()
        {
            _name = Resources.SHAPE_BOX;
        }
        public Box(Size sz, Color c)
            : base(sz, c)
        {
            _name = Resources.SHAPE_BOX;
        }
        public override void DrawShape(Graphics gr, int x, int y)
        {
            Pen p = new Pen(ShapeColor);
            gr.DrawRectangle(p, new Rectangle(x, y, ShapeSize.Width, ShapeSize.Height));
            p.Dispose();
        }
    }
    public class Triangle : Shape
    {
        public Triangle()
            : base()
        {
            _name = Resources.SHAPE_TRIANGLE;
        }
        public Triangle(Size sz, Color c)
            : base(sz, c)
        {
            _name = Resources.SHAPE_TRIANGLE;
        }
        public override void DrawShape(Graphics gr, int x, int y)
        {
            Pen p = new Pen(ShapeColor);
            Point[] pt = new Point[3];
            pt[0] = new Point(x, y + ShapeSize.Height);
            pt[1] = new Point(x + ShapeSize.Width / 2, y);
            pt[2] = new Point(x + ShapeSize.Width, y + ShapeSize.Height);
            gr.DrawPolygon(p, pt);
            p.Dispose();
        }
    }
}
